searchData={"content_type":"text/markdown","items":[{"doc":"Mash is a deadly simple tool for writing CI pipelines in Elixir.","ref":"Mash.html","title":"Mash","type":"module"},{"doc":"Add mash to your dependencies like so:\n\n```elixir\ndef deps do\n  [\n    {:mash, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"Mash.html#module-installation","title":"Installation - Mash","type":"module"},{"doc":"To configure your job pipeline, create a `.mash.exs` file at the root of your project containing a module which implements a `jobs/0` function:\n\n```elixir\ndefmodule MashConfig do\n  import Mash.Helpers\n\n  def jobs do\n    [\n      %{\n        name: :test,\n        run: mix(\"test\")\n      },\n      %{\n        name: :credo, \n        run: mix(\"credo\", [\"--all\"])\n      },\n    ]\n  end\nend\n```\n\nEach entry in the jobs list must, at a minimum, have two keys:\n\n- `:name` -- the name of the job which must be a unique atom\n- `:run` -- a function which defines the work for the job to do. We recommend using the helper functions from Mash.Helpers to define your run function, as they ensure that your function handles setup and teardown correctly for many common scenarios, e.g.:\n    - `Mash.Helpers.mix(task_name, args)` -- execute a mix task with the given `task_name` and `args`.\n    - `Mash.Helpers.shell(command, args)` -- run an executable/script named `command` with `args`.\n    - `Mash.Helpers.fun(fn -> ... end)` -- execute the Elixir function given. This function must return `:ok` or `{:ok, value}` to indicate success, or return `{:error, error}` or `raise` to indicate job failure.\n\nOptionally, a job may also contain a key `needs` whose value is an array of other jobs that must pass before this job will be run.","ref":"Mash.html#module-configuring-pipelines","title":"Configuring pipelines - Mash","type":"module"},{"doc":"```shell\nmix mash\n```","ref":"Mash.html#module-running","title":"Running - Mash","type":"module"},{"doc":"Full documentation is available on [HexDocs](https://hexdocs.pm/mash).","ref":"Mash.html#module-full-documentation","title":"Full Documentation - Mash","type":"module"},{"doc":"Configuration module backed by an agent.","ref":"Mash.Config.html","title":"Mash.Config","type":"behaviour"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Mash.Config.html#child_spec/1","title":"Mash.Config.child_spec/1","type":"function"},{"doc":"","ref":"Mash.Config.html#jobs/0","title":"Mash.Config.jobs/0","type":"function"},{"doc":"","ref":"Mash.Config.html#c:jobs/0","title":"Mash.Config.jobs/0","type":"callback"},{"doc":"","ref":"Mash.Config.html#module/0","title":"Mash.Config.module/0","type":"function"},{"doc":"","ref":"Mash.Config.html#start_link/0","title":"Mash.Config.start_link/0","type":"function"},{"doc":"Wraps execution of a job run function in a Task and a StringIO for tracking output.","ref":"Mash.Execution.html","title":"Mash.Execution","type":"module"},{"doc":"","ref":"Mash.Execution.html#run/1","title":"Mash.Execution.run/1","type":"function"},{"doc":"Helpers that provide a simple way to write Mash configs.","ref":"Mash.Helpers.html","title":"Mash.Helpers","type":"module"},{"doc":"Create a run function for a job that executes a mix task with name `task_name` and the arguments `args`.\n\nAvailable opts:\n- `:env` -- a list of {key, value} pairs that will be used as environment variables.","ref":"Mash.Helpers.html#mix/3","title":"Mash.Helpers.mix/3","type":"function"},{"doc":"Restore a cache file.\n\n- `name` is the base name of the archive to save (default: \".mash-cache\")","ref":"Mash.Helpers.html#restore_cache/1","title":"Mash.Helpers.restore_cache/1","type":"function"},{"doc":"Save a cache file as a gzipped tar archive. We use tar because it preserves timestamps which are used\nby Elixir for determining \"staleness\" of compilation.\n\n- `name` is the base name of the archive to save (default: `\".mash-cache\"`)\n- `files` is the list of files/directories to save in the archive (default:` [\"deps\", \"_build\"]`)","ref":"Mash.Helpers.html#save_cache/2","title":"Mash.Helpers.save_cache/2","type":"function"},{"doc":"Create a run function which executes the script/binary named `command` with the arguments `args`.\n\nAvailable opts:\n- `:env` -- a list of {key, value} pairs that will be used as environment variables.","ref":"Mash.Helpers.html#shell/3","title":"Mash.Helpers.shell/3","type":"function"},{"doc":"Structure that represents the configuration and status of one Mash job.","ref":"Mash.Job.html","title":"Mash.Job","type":"module"},{"doc":"","ref":"Mash.Job.html#from_map/1","title":"Mash.Job.from_map/1","type":"function"},{"doc":"","ref":"Mash.Job.html#validate/1","title":"Mash.Job.validate/1","type":"function"},{"doc":"The process that runs the jobs through a series of Tasks, writes the IO, and monitors the results.","ref":"Mash.Runner.html","title":"Mash.Runner","type":"module"},{"doc":"","ref":"Mash.Runner.html#any_running?/1","title":"Mash.Runner.any_running?/1","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Mash.Runner.html#child_spec/1","title":"Mash.Runner.child_spec/1","type":"function"},{"doc":"","ref":"Mash.Runner.html#start_link/1","title":"Mash.Runner.start_link/1","type":"function"},{"doc":"","ref":"Mash.Runner.html#tick/0","title":"Mash.Runner.tick/0","type":"function"},{"doc":"","ref":"Mash.Runner.html#tick_job/2","title":"Mash.Runner.tick_job/2","type":"function"},{"doc":"","ref":"Mash.Runner.html#t:job_state/0","title":"Mash.Runner.job_state/0","type":"type"},{"doc":"","ref":"Mash.Runner.html#t:result/0","title":"Mash.Runner.result/0","type":"type"},{"doc":"Task to run Mash jobs.","ref":"Mix.Tasks.Mash.html","title":"mix mash","type":"task"},{"doc":"","ref":"Mix.Tasks.Mash.html#run/1","title":"Mix.Tasks.Mash.run/1","type":"function"}]}